<?php
namespace App\Http\Controllers\Shiftlog;

use App\Http\Controllers\Controller;
use App\Models\MasterEquipment;
use App\Models\MasterShift;
use App\Models\MasterStations;
use App\Models\ShiftlogAttendance;
use App\Models\ShiftLogGAEntry;
use App\Models\ShiftlogStandingInstruction;
use App\Models\User;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Validator;

class ShiftlogController extends Controller
{
    /**
     * Write code on Method
     *
     * @return response()
     */
    public function attendance()
    {
        $user = auth()->user();
        if (Auth::check()) {
            $control_center = dd_masters("control_center", "control_center_code");
            $function = dd_masters("function", "function_code");
            $shift = dd_masters("shift", "shift_code");

            return view('shiftlog.attendance', ['control_center' => $control_center, 'function' => $function, 'shift' => $shift]);
        } else {
            return redirect("/")->withSuccess('Opps! You do not have access');

        }
    }
    public function attendancePost(Request $request)
    {
        $alldata = $request->all();
        if (isset($alldata['device'])) {
            $device = $alldata['device'];
        } else {
            $device = "Mobile";
        }
        $validator = Validator::make($alldata, [
            'attendance_date' => ['required'],
            'control_center_code' => ['required'],
            'shift_code' => ['required'],
            'function_code' => ['required'],
        ]);

        if ($validator->fails()) {
            if ($device == "web") {
                return back()->with(["status" => "failed", "code" => config("constants.CODE_FAILURE"), "msg" => $validator->errors()->first(), "errors" => $validator->errors()]);
            } else {
                $logs = array(
                    'module' => "ShiftLog",
                    'user' => $alldata['user_id'],
                    'access_device' => $device,
                    'called_api' => route('attendance'),
                    'called_to' => "web",
                    'request_data' => json_encode($alldata),
                    'response_data' => $validator->errors()->first(),
                    'method_name' => "POST",

                );
                $log = manageLogs($logs);
                return response()->json(["status" => "failed", "code" => config("constants.CODE_FAILURE"), "msg" => $validator->errors()->first()]);
            }
        } else {
            $data['attendance_date'] = $alldata['attendance_date'];
            $data['control_center_code'] = $alldata['control_center_code'];
            $data['shift_code'] = $alldata['shift_code'];
            $data['function_code'] = $alldata['function_code'];
            $data['login_time'] = date("H:i:s");
            $data['logout_time'] = "";
            $data['user_id'] = $alldata['user_id'];
            $data['created_at'] = date("Y-m-d H:i:s");
            $data['updated_at'] = date("Y-m-d H:i:s");
            $data['status'] = "LoggedIn";

            $create = ShiftlogAttendance::insertGetId($data);
            if ($create) {
                if ($device == "web") {
                    return back()->with(["status" => 200, "msg" => "Attendance submitted successfully.", "code" => config("constants.CODE_SUCCESS")]);
                } else {
                    $logs = array(
                        'module' => "Shiftlog",
                        'user' => $alldata['user_id'],
                        'access_device' => $device,
                        'called_api' => route('attendance'),
                        'called_to' => "web",
                        'request_data' => json_encode($alldata),
                        'response_data' => "Logged in successfully!",
                        'method_name' => "POST",

                    );
                    $log = manageLogs($logs);
                    return response()->json(["status" => 200, "msg" => "Attendance submitted successfully.", "code" => config("constants.CODE_SUCCESS")]);
                }
            } else {
                if ($device == "web") {
                    return back()->with(["status" => config("constants.OK"), "code" => config("constants.CODE_FAILURE"), 'msg' => 'Failed! Please try again.']);
                } else {
                    $logs = array(
                        'module' => "Shiftlog",
                        'user' => $alldata['user_id'],
                        'access_device' => $device,
                        'called_api' => route('attendance'),
                        'called_to' => "web",
                        'request_data' => json_encode($alldata),
                        'response_data' => "Failed! Please try again.",
                        'method_name' => "POST",

                    );
                    $log = manageLogs($logs);
                    return response()->json(["status" => config("constants.OK"), "code" => config("constants.CODE_FAILURE"), 'msg' => 'Failed! Please try again.']);
                }
            }
        }
    }
/*Standing Instruction*/
    public function standingInstruction()
    {
        $user = auth()->user();
        if (Auth::check()) {
            $ga = dd_masters("ga", "ga_code");
            return view('shiftlog.standing_instruction', ['ga' => $ga]);
        } else {
            return redirect("/")->withSuccess('Opps! You do not have access');

        }
    }
    public function standingInstructionPost(Request $request)
    {
        $alldata = $request->all();
        if (isset($alldata['device'])) {
            $device = $alldata['device'];
        } else {
            $device = "Mobile";
        }
        $validator = Validator::make($alldata, [
            'instruction_date' => ['required'],
            'ga_code' => ['required'],
            'instruction' => ['required'],
            'instruction_validity' => ['required'],
        ]);

        if ($validator->fails()) {
            if ($device == "web") {
                return back()->with(["status" => "failed", "code" => config("constants.CODE_FAILURE"), "msg" => $validator->errors()->first(), "errors" => $validator->errors()]);
            } else {
                $logs = array(
                    'module' => "ShiftLog",
                    'user' => $alldata['user_id'],
                    'access_device' => $device,
                    'called_api' => route('standingInstruction'),
                    'called_to' => "web",
                    'request_data' => json_encode($alldata),
                    'response_data' => $validator->errors()->first(),
                    'method_name' => "POST",

                );
                $log = manageLogs($logs);
                return response()->json(["status" => "failed", "code" => config("constants.CODE_FAILURE"), "msg" => $validator->errors()->first()]);
            }
        } else {
            $data['instruction_date'] = $alldata['instruction_date'];
            $data['ga_code'] = $alldata['ga_code'];
            $data['instruction'] = $alldata['instruction'];
            $data['instruction_validity'] = $alldata['instruction_validity'];
            $data['user_id'] = $alldata['user_id'];
            $data['created_at'] = date("Y-m-d H:i:s");
            $data['updated_at'] = date("Y-m-d H:i:s");
            $data['status'] = "Active";

            $create = ShiftlogStandingInstruction::insertGetId($data);
            if ($create) {
                if ($device == "web") {
                    return back()->with(["status" => 200, "msg" => "Instruction submitted successfully.", "code" => config("constants.CODE_SUCCESS")]);
                } else {
                    $logs = array(
                        'module' => "Shiftlog",
                        'user' => $alldata['user_id'],
                        'access_device' => $device,
                        'called_api' => route('standingInstruction'),
                        'called_to' => "web",
                        'request_data' => json_encode($alldata),
                        'response_data' => "Logged in successfully!",
                        'method_name' => "POST",

                    );
                    $log = manageLogs($logs);
                    return response()->json(["status" => 200, "msg" => "Standing Instruction submitted successfully.", "code" => config("constants.CODE_SUCCESS")]);
                }
            } else {
                if ($device == "web") {
                    return back()->with(["status" => config("constants.OK"), "code" => config("constants.CODE_FAILURE"), 'msg' => 'Failed! Please try again.']);
                } else {
                    $logs = array(
                        'module' => "Shiftlog",
                        'user' => $alldata['user_id'],
                        'access_device' => $device,
                        'called_api' => route('standingInstruction'),
                        'called_to' => "web",
                        'request_data' => json_encode($alldata),
                        'response_data' => "Failed! Please try again.",
                        'method_name' => "POST",

                    );
                    $log = manageLogs($logs);
                    return response()->json(["status" => config("constants.OK"), "code" => config("constants.CODE_FAILURE"), 'msg' => 'Failed! Please try again.']);
                }
            }
        }
    }
//GA Log Entry
    public function EnterGALog(Request $request)
    {
        $alldata = $request->all();
        //print_r($alldata); exit;
        $shift_time = explode("-", $alldata['start_end_time']);
        if ($alldata['source'] == "web") {
            if ($alldata['action_generated'] == "Add") {
                $status = 0;
            } else {
                $status = 1;
            }
        } else {
            $status = $alldata['status'];
        }
        $data = array(
            "userId" => $alldata['user_id'],
            "ga_day" => $alldata['attendance_date'],
            "shift" => $alldata['shift_code'],
            "start_time" => $shift_time[0],
            "end_time" => $shift_time[1],
            "function" => $alldata['function_code'],
            "equipment" => $alldata['equipment'],
            "sub_equipment" => $alldata['sub_equipment'],
            "station" => $alldata['station'],
            "status" => $status,
        );
        //print_r($data);exit;
        if(isset($alldata['operationId'])){
            $sql = ShiftLogGAEntry::where('id', $alldata['operationId'])->update($data);
        }else{
            $sql = ShiftLogGAEntry::create($data);
        }
//Edit Function
$singleLogEntry = array();
if (isset($request->edit) && $request->edit != "") {
    $singleLogEntry = ShiftLogGAEntry::where('id', $id)->get();
}
//Edit Function
        if ($sql) {
            if (isset($alldata['device']) && $alldata['source'] == "web") {
                return back()->with(["status" => "failed", "code" => config("constants.CODE_SUCCESS"), "msg" => "Last Operation Successful"]);
            } else {
                return response()->json(["status" => config("constants.OK"), "code" => config("constants.CODE_SUCCESS"), 'msg' => 'Record inserted successfully!']);
            }
        }
    }

    public function GALog(Request $request)
    {
        $user = auth()->user();
        //print_r($user); exit;
        if (Auth::check()) {
            $ga = $user['ga'];
            //print $ga; exit;
            $alldata = $request->all();
            //print_r($alldata); exit;
            $uid = $user['userId'];
            $function = dd_masters("function", "function_code");
            $shift = dd_masters("shift", "shift_code");
            $roles = array('CCC/HO Head', 'GA Heads', 'GA Engineers', 'GA Executives', 'GA Executives');
            $date = date("Y-m-d");
            $userAttendanceDetails = ShiftlogAttendance::where('user_id', $uid)->where('attendance_date', 'LIKE', "%{$date}%")->get();
            if (count($userAttendanceDetails) >= 1) {
                $startEndTimeDetails = MasterShift::where('shift_name', $userAttendanceDetails[0]['shift_code'])->get();
                $startEndTime = $startEndTimeDetails[0]['start_time'] . '-' . $startEndTimeDetails[0]['end_time'];
            } else {
                $startEndTime = "";
            }
            $user = User::whereIn('role', $roles)->where('ga', $ga)->get();
            $equipments = MasterEquipment::where('status', 'Active')->get();
            $stations = MasterStations::where('status', 'Active')->get();
            /* echo "<pre/>";
            print_r($equipments); exit; */
            //All Logs
            $allLogsEntry = ShiftLogGAEntry::all();
            //All Logs
            $editValues = array();
            if(!empty($alldata)){
                if($alldata['action']!==null){
                $editValues = ShiftLogGAEntry::where('id', $alldata['id'])->get();
                }
            }
            //print_r($editValues); exit;
            return view('shiftlog.ga_log_entry', ['editValues'=>$editValues,'function' => $function, 'shift' => $shift, 'roles' => $roles, 'user' => $user, 'userAttendanceDetails' => $userAttendanceDetails, 'allLogsEntry' => $allLogsEntry, 'startEndTime' => $startEndTime, 'equipments' => $equipments, 'stations' => $stations]);
        } else {
            return redirect("/")->withSuccess('Opps! You do not have access');

        }
    }
    //GA Log Entry
    //CCC Log Entry
    public function EnterCCCLog(Request $request)
    {
        $alldata = $request->all();
        $shift_time = explode("-", $alldata['start_end_time']);
        if ($alldata['source'] == "web") {
            $status = 0;
        } else {
            $status = $alldata['status'];
        }
        $data = array(
            "userId" => $alldata['user_id'],
            "ga_day" => $alldata['attendance_date'],
            "shift" => $alldata['shift_code'],
            "start_time" => $shift_time[0],
            "end_time" => $shift_time[1],
            "function" => $alldata['function_code'],
            "status" => $status,
        );
        //print_r($data);exit;
        $sql = ShiftLogGAEntry::create($data);
        if ($sql) {
            if (isset($alldata['device']) && $alldata['source'] == "web") {
                return back()->with(["status" => "failed", "code" => config("constants.CODE_SUCCESS"), "msg" => "Record insertion successful"]);
            } else {
                return response()->json(["status" => config("constants.OK"), "code" => config("constants.CODE_SUCCESS"), 'msg' => 'Record inserted successfully!']);
            }
        }
    }

    public function CCCLog(Request $request)
    {
        $user = auth()->user();
        if (Auth::check()) {
            $function = dd_masters("function", "function_code");
            $shift = dd_masters("shift", "shift_code");
            $roles = array('CCC/HO Head', 'GA Heads', 'GA Engineers', 'GA Executives');
            $user = User::whereIn('role', $roles)->get();
            /* echo "<pre/>";
            print_r($user); exit; */
            //All Logs
            $allLogsEntry = ShiftLogGAEntry::all();
            //All Logs
            return view('shiftlog.ga_log_entry', ['function' => $function, 'shift' => $shift, 'user' => $user, 'allLogsEntry' => $allLogsEntry]);
        } else {
            return redirect("/")->withSuccess('Opps! You do not have access');

        }
    }
    //CCC Log Entry
    public function getShift(Request $request)
    {
        $data = $request->all();
        $shift = $data['shift'];
        $sql = MasterShift::where('shift_name', "$shift")->get();
        $data = array("start_time" => $sql[0]['start_time'], "end_time" => $sql[0]['end_time']);
        return json_encode($data);
    }
}
